@@ -351,8 +351,7 @@ gedit_file_browser_widget_finalize (GObject *object)
 	g_object_unref (obj->priv->bookmarks_store);
 	g_object_unref (obj->priv->combo_model);
 
-	g_slist_foreach (obj->priv->filter_funcs, (GFunc)filter_func_free, NULL);
-	g_slist_free (obj->priv->filter_funcs);
+	g_slist_free_full (obj->priv->filter_funcs, (GDestroyNotify) filter_func_free);
 
 	for (loc = obj->priv->locations; loc; loc = loc->next)
 		location_free ((Location *) (loc->data));
@@ -366,7 +365,8 @@ gedit_file_browser_widget_finalize (GObject *object)
 
 	cancel_async_operation (obj);
 
-	gdk_cursor_unref (obj->priv->busy_cursor);
+	if (obj->priv->busy_cursor)
+		g_object_unref (obj->priv->busy_cursor);
 
 	g_free (obj->priv->filter_pattern_str);
 
@@ -742,7 +742,11 @@ fill_combo_model (GeditFileBrowserWidget *obj)
 			    COLUMN_ICON, icon,
 			    COLUMN_NAME, _("Bookmarks"),
 			    COLUMN_ID, BOOKMARKS_ID, -1);
-	g_object_unref (icon);
+
+	if (icon != NULL)
+	{
+		g_object_unref (icon);
+	}
 
 	gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX (obj->priv->combo),
 					      separator_func, obj, NULL);
@@ -1353,8 +1357,7 @@ gedit_file_browser_widget_get_first_selected (GeditFileBrowserWidget *obj,
 
 	result = gtk_tree_model_get_iter (model, iter, (GtkTreePath *)(rows->data));
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 
 	return result;
 }
@@ -1494,8 +1497,7 @@ get_deletable_files (GeditFileBrowserWidget *obj) {
 		paths = g_list_append (paths, gtk_tree_path_copy (path));
 	}
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 
 	return paths;
 }
@@ -1530,8 +1532,7 @@ delete_selected_files (GeditFileBrowserWidget *obj,
 	result = gedit_file_browser_store_delete_all (GEDIT_FILE_BROWSER_STORE (model),
 						      rows, trash);
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 
 	return result == GEDIT_FILE_BROWSER_STORE_RESULT_OK;
 }
@@ -2108,8 +2109,7 @@ gedit_file_browser_widget_get_num_selected_files_or_directories (GeditFileBrowse
 		}
 	}
 
-	g_list_foreach (rows, (GFunc)gtk_tree_path_free, NULL);
-	g_list_free (rows);
+	g_list_free_full (rows, (GDestroyNotify) gtk_tree_path_free);
 
 	return result;
 }
@@ -2159,7 +2159,7 @@ set_busy (GeditFileBrowserWidget *obj,
 	{
 		cursor = gdk_cursor_new (GDK_WATCH);
 		gdk_window_set_cursor (window, cursor);
-		gdk_cursor_unref (cursor);
+		g_object_unref (cursor);
 	}
 	else
 	{
@@ -2227,8 +2227,7 @@ try_activate_drive (GeditFileBrowserWidget *widget,
 		try_mount_volume (widget, volume);
 	}
 
-	g_list_foreach (volumes, (GFunc)g_object_unref, NULL);
-	g_list_free (volumes);
+	g_list_free_full (volumes, g_object_unref);
 }
 
 static void
@@ -2507,6 +2506,9 @@ file_open  (GeditFileBrowserWidget *obj,
 
 	if (!FILE_IS_DIR (flags) && !FILE_IS_DUMMY (flags))
 		g_signal_emit (obj, signals[LOCATION_ACTIVATED], 0, location);
+
+	if (location)
+		g_object_unref (location);
 }
 
 static gboolean
@@ -2542,6 +2544,7 @@ directory_open (GeditFileBrowserWidget *obj,
 		}
 
 		g_free (uri);
+		g_object_unref (location);
 	}
 
 	return result;
@@ -2589,11 +2592,6 @@ on_virtual_root_changed (GeditFileBrowserStore  *model,
 			 GeditFileBrowserWidget *obj)
 {
 	GtkTreeIter iter;
-	GFile *location;
-	GtkTreeIter root;
-	GtkAction *action;
-	Location *loc;
-	GdkPixbuf *pixbuf;
 
 	if (gtk_tree_view_get_model (GTK_TREE_VIEW (obj->priv->treeview)) !=
 	    GTK_TREE_MODEL (obj->priv->file_store))
@@ -2603,14 +2601,22 @@ on_virtual_root_changed (GeditFileBrowserStore  *model,
 
 	if (gedit_file_browser_store_get_iter_virtual_root (model, &iter))
 	{
+		GFile *location;
+		GtkTreeIter root;
+
 		gtk_tree_model_get (GTK_TREE_MODEL (model), &iter,
 				    GEDIT_FILE_BROWSER_STORE_COLUMN_LOCATION,
 				    &location, -1);
 
 		if (gedit_file_browser_store_get_iter_root (model, &root))
 		{
+			GtkAction *action;
+
 			if (!obj->priv->changing_location)
 			{
+				Location *loc;
+				GdkPixbuf *pixbuf;
+
 				/* Remove all items from obj->priv->current_location on */
 				if (obj->priv->current_location)
 					clear_next_locations (obj);
@@ -2649,7 +2655,6 @@ on_virtual_root_changed (GeditFileBrowserStore  *model,
 
 				if (pixbuf)
 					g_object_unref (pixbuf);
-
 			}
 
 			action = gtk_action_group_get_action (obj->priv->action_group,
@@ -2671,6 +2676,9 @@ on_virtual_root_changed (GeditFileBrowserStore  *model,
 		}
 
 		check_current_item (obj, TRUE);
+
+		if (location)
+			g_object_unref (location);
 	}
 	else
 	{
@@ -2815,7 +2823,7 @@ do_change_directory (GeditFileBrowserWidget *obj,
 
 	if ((event->state &
 	    (~GDK_CONTROL_MASK & ~GDK_SHIFT_MASK & ~GDK_MOD1_MASK)) ==
-	     event->state && event->keyval == GDK_BackSpace)
+	     event->state && event->keyval == GDK_KEY_BackSpace)
 	{
 		action = gtk_action_group_get_action (obj->priv->action_group_sensitive,
 		                                      "DirectoryPrevious");
@@ -2828,15 +2836,15 @@ do_change_directory (GeditFileBrowserWidget *obj,
 
 	switch (event->keyval)
 	{
-		case GDK_Left:
+		case GDK_KEY_Left:
 			action = gtk_action_group_get_action (obj->priv->action_group_sensitive,
 			                                      "DirectoryPrevious");
 			break;
-		case GDK_Right:
+		case GDK_KEY_Right:
 			action = gtk_action_group_get_action (obj->priv->action_group_sensitive,
 			                                      "DirectoryNext");
 			break;
-		case GDK_Up:
+		case GDK_KEY_Up:
 			action = gtk_action_group_get_action (obj->priv->action_group,
 			                                      "DirectoryUp");
 			break;
@@ -2871,7 +2879,8 @@ on_treeview_key_press_event (GeditFileBrowserView   *treeview,
 
 	modifiers = gtk_accelerator_get_default_mod_mask ();
 
-	if (event->keyval == GDK_Delete || event->keyval == GDK_KP_Delete)
+	if (event->keyval == GDK_KEY_Delete ||
+	    event->keyval == GDK_KEY_KP_Delete)
 	{
 
 		if ((event->state & modifiers) == GDK_SHIFT_MASK &&
@@ -2887,7 +2896,7 @@ on_treeview_key_press_event (GeditFileBrowserView   *treeview,
 		}
 	}
 
-	if ((event->keyval == GDK_F2) && (event->state & modifiers) == 0)
+	if ((event->keyval == GDK_KEY_F2) && (event->state & modifiers) == 0)
 	{
 		rename_selected_file (obj);
 		return TRUE;
